# A set of tiny utils

> 整合业界已有的模块, 开始一点一点封装一堆工作常用的工具类, 旨在提供更简单,更快速的方法供大家使用

## 已有工具类:

### ​excel_utils: 处理excel, 如获取指定区域的数据

### config_utils: 处理配置文件(.ini)

### echarts_utils: 处理图表, 如生成折线图

### time_utils: 处理时间, 如返回当前时间等

### csv_utils: 处理csv文件, 如写入数据到csv文件